@@ -1,9 +1,11 @@
 from __future__ import annotations
 
-from typing import Any, List, Mapping, Optional, Sequence, Type
+from typing import Any, Dict, Mapping, Optional, Sequence, Type
 
 
 class Data:
+    id: str
+
     def __init__(self, data: Mapping[str, Any]) -> None:
         for key, value in data.items():
             if isinstance(value, dict):
@@ -38,12 +40,23 @@ class Data:
     def __getitem__(self, name: str) -> Any:
         return self.__getattribute__(name)
 
-    def __int__(self):
-        return self.id if "id" in self.__dict__ else -1
+    def __int__(self) -> int:
+        return int(self.id) if "id" in self.__dict__ else -1
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"{type(self).__name__} - {self.id if 'id' in self.__dict__ else -1}"
 
+    def to_dict(self) -> Dict[str, str]:
+        """
+        Return a dictionary of the data.
+
+        Returns
+        -------
+        Dict[str, str]
+            A dictionary of the data on the object.
+        """
+        return self.__dict__
+
 
 class Alliance(Data):
     """Represents an alliance.
@@ -323,8 +336,8 @@ class Color(Data):
     bloc_name: str
     turn_bonus: int
 
-    def __repr__(self):
-        return f"{type(self).__name__} - {self.name if 'name' in self.__dict__ else -1}"
+    def __repr__(self) -> str:
+        return f"{type(self).__name__} - {self.bloc_name if 'bloc_name' in self.__dict__ else -1}"
 
 
 class Nation(Data):
@@ -671,7 +684,7 @@ class Treasure(Data):
     spawndate: str
     nation: Nation
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"{type(self).__name__} - {self.name if 'name' in self.__dict__ else -1}"
 
 
