@@ -1,6 +1,17 @@
 from __future__ import annotations
 
-from typing import Any, Dict, Mapping, Optional, Sequence, Tuple, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Mapping,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 import requests
 
@@ -22,78 +33,74 @@ from .paginator import AlliancePaginator, NationPaginator, Paginator
 
 class SyncKit(KitBase):
     def _query(
-        self: SyncKit,
+        self,
         endpoint: str,
-        params: Union[str, Mapping[str, Any]],
-        args: Union[str, Sequence[str]],
+        params: Mapping[str, Any],
+        args: Sequence[Union[str, Any]],
         *,
         is_paginator: bool = False,
     ) -> Dict[str, Any]:
         query = query = self._format_query(endpoint, params, args, is_paginator)
         response = requests.request("GET", self.graphql_url(), json={"query": query})
-        response = response.json()
+        data: dict = response.json()
         try:
-            if "errors" in response[0]:
+            if "errors" in data[0]:
                 error = (
-                    "\n".join(i["message"] for i in response[0]["errors"])
-                    if len(response[0]["errors"]) > 1
-                    else response[0]["errors"][0]["message"]
+                    "\n".join(i["message"] for i in data[0]["errors"])
+                    if len(data[0]["errors"]) > 1
+                    else data[0]["errors"][0]["message"]
                 )
                 raise GraphQLError(error)
         except KeyError:
             pass
         try:
-            if "errors" in response:
+            if "errors" in data:
                 error = (
-                    "\n".join(i["message"] for i in response["errors"])
-                    if len(response["errors"]) > 1
-                    else response["errors"][0]["message"]
+                    "\n".join(i["message"] for i in data["errors"])
+                    if len(data["errors"]) > 1
+                    else data["errors"][0]["message"]
                 )
                 raise GraphQLError(error)
         except KeyError:
             pass
-        return response
+        return data
 
     def _data_query(
-        self: SyncKit,
+        self,
         endpoint: str,
-        params: Union[str, Mapping[str, Any]],
+        params: Mapping[str, Any],
         arg: Union[str, Mapping[str, Any]],
         *args: Union[str, Mapping[str, Any]],
         paginator: bool = False,
         is_paginator: bool = False,
-        type_: Data,
-        paginator_type: Optional[Paginator] = None,
+        type_: Type[Data],
+        paginator_type: Optional[Type[Paginator]] = None,
         **kwargs: Any,
-    ) -> Union[Tuple[Data], Paginator]:
+    ) -> Union[Tuple[Data, ...], Paginator]:
         args = (arg, *args)
         params = params or kwargs
         if "first" not in params and endpoint in {"alliance", "nations"}:
-            params["first"] = 5
-        response = self._query(
-            endpoint, params, args, is_paginator=is_paginator
-        )
+            setattr(params, "first", 5)
+        response = self._query(endpoint, params, args, is_paginator=is_paginator)
         if is_paginator and paginator_type:
-            data: Tuple[type_] = tuple(
-                type_(i) for i in response["data"][endpoint]["data"]
-            )
+            data = tuple(type_(i) for i in response["data"][endpoint]["data"])
             if paginator:
                 return paginator_type(
                     data, PaginatorInfo(response["data"][endpoint]["paginatorInfo"])
                 )
             return data
-        data: Tuple[type_] = tuple(type_(i) for i in response["data"][endpoint])
+        data = tuple(type_(i) for i in response["data"][endpoint])
         return data
 
     def alliance_query(
-        self: SyncKit,
-        params: Union[str, Mapping[str, Any]],
+        self,
+        params: Mapping[str, Any],
         arg: Union[str, Mapping[str, Any]],
         *args: Union[str, Mapping[str, Any]],
         paginator: bool = False,
         **kwargs: Any,
-    ) -> Union[Tuple[Alliance], AlliancePaginator]:
-        return self._data_query(
+    ) -> Union[Tuple[Alliance, ...], AlliancePaginator]:
+        data = self._data_query(
             "alliances",
             params,
             arg,
@@ -104,15 +111,21 @@ class SyncKit(KitBase):
             is_paginator=True,
             paginator_type=AlliancePaginator,
         )
+        if TYPE_CHECKING:
+            if isinstance(data, tuple):
+                data = cast(Tuple[Alliance, ...], data)
+            else:
+                data = cast(AlliancePaginator, data)
+        return data
 
     def color_query(
-        self: SyncKit,
-        params: Union[str, Mapping[str, Any]],
+        self,
+        params: Mapping[str, Any],
         arg: Union[str, Mapping[str, Any]],
         *args: Union[str, Mapping[str, Any]],
         **kwargs: Any,
-    ) -> Tuple[Color]:
-        return self._data_query(
+    ) -> Tuple[Color, ...]:
+        data = self._data_query(
             "colors",
             params,
             arg,
@@ -120,16 +133,19 @@ class SyncKit(KitBase):
             **kwargs,
             type_=Color,
         )
+        if TYPE_CHECKING:
+            data = cast(Tuple[Color, ...], data)
+        return data
 
     def nation_query(
-        self: SyncKit,
-        params: Union[str, Mapping[str, Any]],
+        self,
+        params: Mapping[str, Any],
         arg: Union[str, Mapping[str, Any]],
         *args: Union[str, Mapping[str, Any]],
         paginator: bool = False,
         **kwargs: Any,
-    ) -> Union[Tuple[Nation], NationPaginator]:
-        return self._data_query(
+    ) -> Union[Tuple[Nation, ...], NationPaginator]:
+        data = self._data_query(
             "nations",
             params,
             arg,
@@ -140,15 +156,21 @@ class SyncKit(KitBase):
             is_paginator=True,
             paginator_type=NationPaginator,
         )
+        if TYPE_CHECKING:
+            if isinstance(data, tuple):
+                data = cast(Tuple[Nation, ...], data)
+            else:
+                data = cast(NationPaginator, data)
+        return data
 
     def trade_query(
-        self: SyncKit,
-        params: Union[str, Mapping[str, Any]],
+        self,
+        params: Mapping[str, Any],
         arg: Union[str, Mapping[str, Any]],
         *args: Union[str, Mapping[str, Any]],
         **kwargs: Any,
-    ) -> Tuple[Trade]:
-        return self._data_query(
+    ) -> Tuple[Trade, ...]:
+        data = self._data_query(
             "trades",
             params,
             arg,
@@ -156,15 +178,18 @@ class SyncKit(KitBase):
             **kwargs,
             type_=Trade,
         )
+        if TYPE_CHECKING:
+            data = cast(Tuple[Trade, ...], data)
+        return data
 
     def trade_price_query(
-        self: SyncKit,
-        params: Union[str, Mapping[str, Any]],
+        self,
+        params: Mapping[str, Any],
         arg: Union[str, Mapping[str, Any]],
         *args: Union[str, Mapping[str, Any]],
         **kwargs: Any,
-    ) -> Tuple[Tradeprice]:
-        return self._data_query(
+    ) -> Tuple[Tradeprice, ...]:
+        data = self._data_query(
             "tradeprices",
             params,
             arg,
@@ -172,15 +197,18 @@ class SyncKit(KitBase):
             **kwargs,
             type_=Tradeprice,
         )
+        if TYPE_CHECKING:
+            data = cast(Tuple[Tradeprice, ...], data)
+        return data
 
     def treasure_query(
-        self: SyncKit,
-        params: Union[str, Mapping[str, Any]],
+        self,
+        params: Mapping[str, Any],
         arg: Union[str, Mapping[str, Any]],
         *args: Union[str, Mapping[str, Any]],
         **kwargs: Any,
-    ) -> Tuple[Treasure]:
-        return self._data_query(
+    ) -> Tuple[Treasure, ...]:
+        data = self._data_query(
             "treasures",
             params,
             arg,
@@ -188,15 +216,18 @@ class SyncKit(KitBase):
             **kwargs,
             type_=Treasure,
         )
+        if TYPE_CHECKING:
+            data = cast(Tuple[Treasure, ...], data)
+        return data
 
     def war_query(
-        self: SyncKit,
-        params: Union[str, Mapping[str, Any]],
+        self,
+        params: Mapping[str, Any],
         arg: Union[str, Mapping[str, Any]],
         *args: Union[str, Mapping[str, Any]],
         **kwargs: Any,
-    ) -> Tuple[War]:
-        return self._data_query(
+    ) -> Tuple[War, ...]:
+        data = self._data_query(
             "wars",
             params,
             arg,
@@ -204,3 +235,6 @@ class SyncKit(KitBase):
             **kwargs,
             type_=War,
         )
+        if TYPE_CHECKING:
+            data = cast(Tuple[War, ...], data)
+        return data
